@@ -1,4 +1,8 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 #
 # Copyright 2016-2017 David Steele <steele@debian.org>
@@ -11,7 +15,7 @@ import logging
 import time
 from functools import wraps
 from dbus.exceptions import DBusException
-import iwscan
+from comitup import iwscan
 
 
 from gi.repository.GLib import MainLoop, timeout_add
@@ -19,10 +23,10 @@ if __name__ == '__main__':
     from dbus.mainloop.glib import DBusGMainLoop
     DBusGMainLoop(set_as_default=True)
 
-import nmmon    # noqa
-import nm       # noqa
-import mdns     # noqa
-import modemgr  # noqa
+from comitup import nmmon    # noqa
+from comitup import nm       # noqa
+from comitup import mdns     # noqa
+from comitup import modemgr  # noqa
 
 
 log = logging.getLogger('comitup')
